# To build all parts of alcotest requires the async, js_of_ocaml, and lwt
# packages.  The async package in particular requires many packages that test
# with alcotest.  We build only the base alcotest package to break the circular
# dependency.
%bcond_with async

%global srcname alcotest

Name:           ocaml-%{srcname}
Version:        1.9.0
Release:        %mkrel 1
Summary:        Lightweight and colorful test framework for OCaml
Group:          Development/OCaml

License:        ISC
URL:            https://github.com/mirage/alcotest
Source0:        %{URL}/archive/%{version}.tar.gz#/%{srcname}-%{version}.tar.gz
# We neither need nor want the stdlib-shims or ocaml-syntax-shims packages in
# Fedora.  They are forward compatibility packages for older OCaml
# installations.  Patch them out instead.  Upstream does not want this patch
# until stdlib-shims and ocaml-syntax-shims are obsolete.
Patch:          0001-Drop-the-stdlib-shims-subpackage.patch

BuildRequires:  ocaml >= 4.08.0
BuildRequires:  ocaml-astring-devel
BuildRequires:  ocaml-cmdliner-devel >= 1.2.0
BuildRequires:  ocaml-dune >= 3.0
BuildRequires:  ocaml-fmt-devel >= 0.8.7
BuildRequires:  ocaml-re-devel >= 1.7.2
BuildRequires:  ocaml-uutf-devel >= 1.0.1

%if %{with async}
BuildRequires:  js-of-ocaml-compiler-devel >= 3.11.0
BuildRequires:  ocaml-async-devel >= 0.16.0
BuildRequires:  ocaml-async-kernel-devel
BuildRequires:  ocaml-async-unix-devel >= 0.16.0
BuildRequires:  ocaml-base-devel
BuildRequires:  ocaml-core-devel >= 0.16.0
BuildRequires:  ocaml-core-unix-devel >= 0.16.0
BuildRequires:  ocaml-logs-devel
BuildRequires:  ocaml-lwt-devel
%endif

%description
Alcotest is a lightweight and colorful test framework.

Alcotest exposes a simple interface to perform unit tests, including a
simple `TESTABLE` module type, a `check` function to assert test
predicates, and a `run` function to perform a list of `unit -> unit`
test callbacks.

Alcotest provides quiet and colorful output where only faulty runs are
fully displayed at the end of the run (with the full logs ready to
inspect), with a simple (yet expressive) query language to select the
tests to run.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       ocaml-astring-devel%{?_isa}
Requires:       ocaml-cmdliner-devel%{?_isa}
Requires:       ocaml-fmt-devel%{?_isa}
Requires:       ocaml-re-devel%{?_isa}
Requires:       ocaml-uutf-devel%{?_isa}

%if %{with async}
Requires:       ocaml-async-devel
Requires:       ocaml-lwt-devel
%endif

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -n %{srcname}-%{version} -p1

%build
%dune_build %{!?with_async:-p alcotest}

%install
%dune_install %{!?with_async:alcotest}

%check
%dune_check %{!?with_async:-p alcotest}

%files -f .ofiles
%doc CHANGES.md README.md alcotest-help.txt
%license LICENSE.md

%files devel -f .ofiles-devel



%changelog
* Fri Apr 04 2025 pterjan <pterjan> 1.9.0-1.mga10
+ Revision: 2173504
- Update to 1.9.0

* Sat Oct 08 2022 pterjan <pterjan> 1.6.0-1.mga9
+ Revision: 1895583
- Update to 1.6.0

* Thu May 19 2022 pterjan <pterjan> 1.5.0-3.mga9
+ Revision: 1859202
- Rebuild for OCaml 4.14

* Wed May 18 2022 pterjan <pterjan> 1.5.0-2.mga9
+ Revision: 1858602
- Rebuild for new ocaml-uutf

* Wed Oct 13 2021 tv <tv> 1.5.0-1.mga9
+ Revision: 1751105
- Version 1.5.0
- OCaml 4.13.1 build

* Sat Mar 06 2021 tv <tv> 1.3.0-3.mga9
+ Revision: 1699927
- 1.3.0
- rebuild for ocaml-4.2-12

* Sun Jan 10 2021 pterjan <pterjan> 1.0.1-2.mga8
+ Revision: 1670767
- Rebuild to generate ocamlx provides

* Sun Apr 05 2020 tv <tv> 1.0.1-1.mga8
+ Revision: 1564926
- 1.0.1

* Fri Feb 28 2020 umeabot <umeabot> 1.0.0-4.mga8
+ Revision: 1551802
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 1.0.0-3.mga8
+ Revision: 1545757
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 tv <tv> 1.0.0-2.mga8
+ Revision: 1485163
- imported package ocaml-alcotest

